getcert

package
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2026 License: AGPL-3.0 Imports: 36 Imported by: 0

Documentation

Overview

Package getcert implements the get-cert subcommand: it requests a TLS certificate from CDS by proving the caller runs inside a TEE.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCmd

func NewCmd() *cobra.Command

NewCmd returns the cobra subcommand. It is registered as a child of `c8s` and as the root command of the standalone binary.

Types

This section is empty.

Jump to